/*
 * Copyright 2017-present Open Networking Laboratory
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.opencord.ce.local.bigswitch.cli;

import org.apache.karaf.shell.commands.Argument;
import org.apache.karaf.shell.commands.Command;
import org.onosproject.cli.AbstractShellCommand;
import org.onosproject.net.PortNumber;
import org.opencord.ce.local.bigswitch.BigSwitchService;

/**
 * Returns the connect point associated to the specified port number of the bigswitch.
 */
@Command(scope = "onos", name = "bigswitch-port", description = "Returns the connect point" +
        "associated with the specified virtual port of the bigswitch")
public class ConnectPointFromVirtPortCmd extends AbstractShellCommand {

    @Argument(index = 1, name = "port",
            description = "Virtual bigswitch port",
            required = true, multiValued = false)
    String port = "0";


    @Override
    public void execute() {
        BigSwitchService bigSwitchService = get(BigSwitchService.class);
        print(bigSwitchService.connectPointFromVirtPort(PortNumber.fromString(port)).toString());

    }
}
